@@ -187,6 +187,11 @@ static const GimpStringActionEntry filters_actions[] =
     "gegl:deinterlace",
     NULL /* FIXME GIMP_HELP_FILTER_DEINTERLACE */ },
 
+  { "filters-desaturate", GIMP_STOCK_TOOL_DESATURATE,
+    NC_("filters-action", "_Desaturate..."), NULL, NULL,
+    "gimp:desaturate",
+    GIMP_HELP_TOOL_DESATURATE },
+
   { "filters-difference-of-gaussians", GIMP_STOCK_GEGL,
     NC_("filters-action", "Difference of Gaussians..."), NULL, NULL,
     "gegl:difference-of-gaussians",
@@ -262,6 +267,11 @@ static const GimpStringActionEntry filters_actions[] =
     "gegl:grid",
     NULL /* FIXME GIMP_HELP_FILTER_GAUSSIAN_GRID */ },
 
+  { "filters-high-pass", GIMP_STOCK_GEGL,
+    NC_("filters-action", "_High Pass..."), NULL, NULL,
+    "gegl:high-pass",
+    NULL /* FIXME GIMP_HELP_FILTER_HIGH_PASS */ },
+
   { "filters-illusion", GIMP_STOCK_GEGL,
     NC_("filters-action", "_Illusion..."), NULL, NULL,
     "gegl:illusion",
@@ -402,6 +412,11 @@ static const GimpStringActionEntry filters_actions[] =
     "gegl:polar-coordinates",
     NULL /* FIXME GIMP_HELP_FILTER_POLAR_COORDINATES */ },
 
+  { "filters-posterize", GIMP_STOCK_TOOL_POSTERIZE,
+    NC_("filters-action", "_Posterize..."), NULL, NULL,
+    "gimp:posterize",
+    GIMP_HELP_TOOL_POSTERIZE },
+
   { "filters-red-eye-removal", GIMP_STOCK_GEGL,
     NC_("filters-action", "_Red Eye Removal..."), NULL, NULL,
     "gegl:red-eye-removal",
@@ -412,10 +427,15 @@ static const GimpStringActionEntry filters_actions[] =
     "gegl:ripple",
     NULL /* FIXME GIMP_HELP_FILTER_RIPPLE */ },
 
+  { "filters-saturation", GIMP_STOCK_GEGL,
+    NC_("filters-action", "Sat_uration..."), NULL, NULL,
+    "gegl:saturation",
+    NULL /* FIXME GIMP_HELP_FILTER_SATURATION */ },
+
   { "filters-semi-flatten", GIMP_STOCK_GEGL,
     NC_("filters-action", "_Semi-Flatten..."), NULL, NULL,
     "gimp:semi-flatten",
-    NULL /* FIXME GIMP_HELP_FILTER_POLAR_COORDINATES */ },
+    NULL /* FIXME GIMP_HELP_FILTER_SEMI_FLATTEN */ },
 
   { "filters-sepia", GIMP_STOCK_GEGL,
     NC_("filters-action", "_Sepia..."), NULL, NULL,
@@ -636,6 +656,7 @@ filters_actions_update (GimpActionGroup *group,
   SET_SENSITIVE ("filters-bump-map",                writable);
   SET_SENSITIVE ("filters-c2g",                     writable && !gray);
   SET_SENSITIVE ("filters-cartoon",                 writable);
+  SET_SENSITIVE ("filters-channel-mixer",           writable);
   SET_SENSITIVE ("filters-checkerboard",            writable);
   SET_SENSITIVE ("filters-color-enhance",           writable && !gray);
   SET_SENSITIVE ("filters-color-exchange",          writable);
@@ -646,6 +667,7 @@ filters_actions_update (GimpActionGroup *group,
   SET_SENSITIVE ("filters-convolution-matrix",      writable);
   SET_SENSITIVE ("filters-cubism",                  writable);
   SET_SENSITIVE ("filters-deinterlace",             writable);
+  SET_SENSITIVE ("filters-desaturate",              writable && !gray);
   SET_SENSITIVE ("filters-difference-of-gaussians", writable);
   SET_SENSITIVE ("filters-diffraction-patterns",    writable);
   SET_SENSITIVE ("filters-displace",                writable);
@@ -661,6 +683,7 @@ filters_actions_update (GimpActionGroup *group,
   SET_SENSITIVE ("filters-gaussian-blur",           writable);
   SET_SENSITIVE ("filters-gaussian-blur-selective", writable);
   SET_SENSITIVE ("filters-grid",                    writable);
+  SET_SENSITIVE ("filters-high-pass",               writable);
   SET_SENSITIVE ("filters-illusion",                writable);
   SET_SENSITIVE ("filters-kaleidoscope",            writable);
   SET_SENSITIVE ("filters-lens-distortion",         writable);
@@ -689,8 +712,10 @@ filters_actions_update (GimpActionGroup *group,
   SET_SENSITIVE ("filters-pixelize",                writable);
   SET_SENSITIVE ("filters-plasma",                  writable);
   SET_SENSITIVE ("filters-polar-coordinates",       writable);
+  SET_SENSITIVE ("filters-posterize",               writable);
   SET_SENSITIVE ("filters-red-eye-removal",         writable && !gray);
   SET_SENSITIVE ("filters-ripple",                  writable);
+  SET_SENSITIVE ("filters-saturation",              writable && !gray);
   SET_SENSITIVE ("filters-semi-flatten",            writable && alpha);
   SET_SENSITIVE ("filters-sepia",                   writable && !gray);
   SET_SENSITIVE ("filters-shift",                   writable);
