@@ -132,18 +132,6 @@ _("The window type hint that is set on dock windows and the toolbox " \
 #define FRACTALEXPLORER_PATH_BLURB \
 "Where to search for fractals used by the Fractal Explorer plug-in."
 
-#define GAMMA_CORRECTION_BLURB \
-"This setting is ignored."
-#if 0
-"Sets the gamma correction value for the display. 1.0 corresponds to no " \
-"gamma correction.  For most displays, gamma correction should be set " \
-"to between 2.0 and 2.6. One important thing to keep in mind: Many images " \
-"that you might get from outside sources will in all likelihood already " \
-"be gamma-corrected.  In these cases, the image will look washed-out if " \
-"GIMP has gamma-correction turned on.  If you are going to work with " \
-"images of this sort, turn gamma correction off by setting the value to 1.0."
-#endif
-
 #define GFIG_PATH_BLURB \
 "Where to search for Gfig figures used by the Gfig plug-in."
 
@@ -293,11 +281,13 @@ _("Sets the default quick mask color.")
 
 #define RESIZE_WINDOWS_ON_RESIZE_BLURB \
 _("When enabled, the image window will automatically resize itself " \
-  "whenever the physical image size changes.")
+  "whenever the physical image size changes. This setting only takes " \
+  "effect in multi-window mode.")
 
 #define RESIZE_WINDOWS_ON_ZOOM_BLURB \
 _("When enabled, the image window will automatically resize itself " \
-  "when zooming into and out of images.")
+  "when zooming into and out of images. This setting only takes " \
+  "effect in multi-window mode.")
 
 #define RESTORE_SESSION_BLURB \
 _("Let GIMP try to restore your last saved session on each startup.")
@@ -388,6 +378,9 @@ _("Enable the N-Point Deformation tool.")
 #define PLAYGROUND_HANDLE_TRANSFORM_TOOL_BLURB \
 _("Enable the Handle Transform tool.")
 
+#define PLAYGROUND_SYMMETRY_BLURB \
+_("Enable symmetry on painting.")
+
 #define PLAYGROUND_MYBRUSH_TOOL_BLURB \
 _("Enable the MyPaint Brush tool.")
 
