@@ -143,16 +143,18 @@ gimp_curve_class_init (GimpCurveClass *klass)
   data_class->get_extension         = gimp_curve_get_extension;
   data_class->duplicate             = gimp_curve_duplicate;
 
-  GIMP_CONFIG_INSTALL_PROP_ENUM (object_class, PROP_CURVE_TYPE,
-                                 "curve-type",
-                                 "The curve type",
-                                 GIMP_TYPE_CURVE_TYPE,
-                                 GIMP_CURVE_SMOOTH, 0);
+  GIMP_CONFIG_PROP_ENUM (object_class, PROP_CURVE_TYPE,
+                         "curve-type",
+                         "Curve Type",
+                         "The curve type",
+                         GIMP_TYPE_CURVE_TYPE,
+                         GIMP_CURVE_SMOOTH, 0);
 
-  GIMP_CONFIG_INSTALL_PROP_INT (object_class, PROP_N_POINTS,
-                                "n-points",
-                                "The number of points",
-                                17, 17, 17, 0);
+  GIMP_CONFIG_PROP_INT (object_class, PROP_N_POINTS,
+                        "n-points",
+                        "Number of Points",
+                        "The number of points",
+                        17, 17, 17, 0);
 
   array_spec = g_param_spec_double ("point", NULL, NULL,
                                     -1.0, 1.0, 0.0, GIMP_PARAM_READWRITE);
@@ -163,10 +165,11 @@ gimp_curve_class_init (GimpCurveClass *klass)
                                                                 GIMP_PARAM_STATIC_STRINGS |
                                                                 GIMP_CONFIG_PARAM_FLAGS));
 
-  GIMP_CONFIG_INSTALL_PROP_INT  (object_class, PROP_N_SAMPLES,
-                                 "n-samples",
-                                 "The number of samples",
-                                 256, 256, 256, 0);
+  GIMP_CONFIG_PROP_INT  (object_class, PROP_N_SAMPLES,
+                         "n-samples",
+                         "Number of Samples",
+                         "The number of samples",
+                         256, 256, 256, 0);
 
   array_spec = g_param_spec_double ("sample", NULL, NULL,
                                     0.0, 1.0, 0.0, GIMP_PARAM_READWRITE);
@@ -309,7 +312,7 @@ gimp_curve_get_property (GObject    *object,
     case PROP_POINTS:
       {
         GimpValueArray *array = gimp_value_array_new (curve->n_points * 2);
-        GValue          v     = { 0, };
+        GValue          v     = G_VALUE_INIT;
         gint            i;
 
         g_value_init (&v, G_TYPE_DOUBLE);
@@ -336,7 +339,7 @@ gimp_curve_get_property (GObject    *object,
     case PROP_SAMPLES:
       {
         GimpValueArray *array = gimp_value_array_new (curve->n_samples);
-        GValue          v     = { 0, };
+        GValue          v     = G_VALUE_INIT;
         gint            i;
 
         g_value_init (&v, G_TYPE_DOUBLE);
