@@ -385,6 +385,10 @@ static const GimpDialogFactoryEntry entries[] =
             N_("Selection"), N_("Selection Editor"), GIMP_STOCK_SELECTION,
             GIMP_HELP_SELECTION_DIALOG,
             dialogs_selection_editor_new, 0, FALSE),
+  DOCKABLE ("gimp-symmetry-editor",
+            N_("Symmetry Painting"), NULL, GIMP_STOCK_SYMMETRY,
+            GIMP_HELP_SYMMETRY_DIALOG,
+            dialogs_symmetry_editor_new, 0, FALSE),
   DOCKABLE ("gimp-undo-history",
             N_("Undo"), N_("Undo History"), GIMP_STOCK_UNDO_HISTORY,
             GIMP_HELP_UNDO_DIALOG,
