@@ -51,6 +51,7 @@ static gint64        gimp_procedure_get_memsize         (GimpObject      *object
 static const gchar * gimp_procedure_real_get_label      (GimpProcedure   *procedure);
 static const gchar * gimp_procedure_real_get_menu_label (GimpProcedure   *procedure);
 static const gchar * gimp_procedure_real_get_blurb      (GimpProcedure   *procedure);
+static const gchar * gimp_procedure_real_get_help_id    (GimpProcedure   *procedure);
 static gboolean      gimp_procedure_real_get_sensitive  (GimpProcedure   *procedure,
                                                          GimpObject      *object);
 static GimpValueArray * gimp_procedure_real_execute     (GimpProcedure   *procedure,
@@ -93,6 +94,7 @@ gimp_procedure_class_init (GimpProcedureClass *klass)
   klass->get_label               = gimp_procedure_real_get_label;
   klass->get_menu_label          = gimp_procedure_real_get_menu_label;
   klass->get_blurb               = gimp_procedure_real_get_blurb;
+  klass->get_help_id             = gimp_procedure_real_get_help_id;
   klass->get_sensitive           = gimp_procedure_real_get_sensitive;
   klass->execute                 = gimp_procedure_real_execute;
   klass->execute_async           = gimp_procedure_real_execute_async;
@@ -184,6 +186,12 @@ gimp_procedure_real_get_blurb (GimpProcedure *procedure)
   return procedure->blurb;
 }
 
+static const gchar *
+gimp_procedure_real_get_help_id (GimpProcedure *procedure)
+{
+  return NULL;
+}
+
 static gboolean
 gimp_procedure_real_get_sensitive (GimpProcedure *procedure,
                                    GimpObject    *object)
@@ -353,6 +361,14 @@ gimp_procedure_get_blurb (GimpProcedure *procedure)
   return GIMP_PROCEDURE_GET_CLASS (procedure)->get_blurb (procedure);
 }
 
+const gchar *
+gimp_procedure_get_help_id (GimpProcedure *procedure)
+{
+  g_return_val_if_fail (GIMP_IS_PROCEDURE (procedure), NULL);
+
+  return GIMP_PROCEDURE_GET_CLASS (procedure)->get_help_id (procedure);
+}
+
 gboolean
 gimp_procedure_get_sensitive (GimpProcedure *procedure,
                               GimpObject    *object)
@@ -495,7 +511,7 @@ GimpValueArray *
 gimp_procedure_get_arguments (GimpProcedure *procedure)
 {
   GimpValueArray *args;
-  GValue          value = { 0, };
+  GValue          value = G_VALUE_INIT;
   gint            i;
 
   g_return_val_if_fail (GIMP_IS_PROCEDURE (procedure), NULL);
@@ -518,7 +534,7 @@ gimp_procedure_get_return_values (GimpProcedure *procedure,
                                   const GError  *error)
 {
   GimpValueArray *args;
-  GValue          value = { 0, };
+  GValue          value = G_VALUE_INIT;
   gint            i;
 
   g_return_val_if_fail (success == FALSE || GIMP_IS_PROCEDURE (procedure),
@@ -737,7 +753,7 @@ gimp_procedure_validate_args (GimpProcedure  *procedure,
         }
       else if (! (pspec->flags & GIMP_PARAM_NO_VALIDATE))
         {
-          GValue string_value = { 0, };
+          GValue string_value = G_VALUE_INIT;
 
           g_value_init (&string_value, G_TYPE_STRING);
 
