@@ -36,6 +36,8 @@
 #include "core/gimpmarshal.h"
 #include "core/gimpparamspecs.h"
 
+#include "file/file-utils.h"
+
 #define __YES_I_NEED_GIMP_PLUG_IN_MANAGER_CALL__
 #include "gimppluginmanager-call.h"
 
@@ -65,6 +67,7 @@ static const gchar * gimp_plug_in_procedure_get_label  (GimpProcedure  *procedur
 static const gchar * gimp_plug_in_procedure_get_menu_label
                                                        (GimpProcedure  *procedure);
 static const gchar * gimp_plug_in_procedure_get_blurb  (GimpProcedure  *procedure);
+static const gchar * gimp_plug_in_procedure_get_help_id(GimpProcedure  *procedure);
 static gboolean   gimp_plug_in_procedure_get_sensitive (GimpProcedure  *procedure,
                                                         GimpObject     *object);
 static GimpValueArray * gimp_plug_in_procedure_execute (GimpProcedure  *procedure,
@@ -82,6 +85,11 @@ static void     gimp_plug_in_procedure_execute_async   (GimpProcedure  *procedur
 
 static GFile  * gimp_plug_in_procedure_real_get_file   (const GimpPlugInProcedure *procedure);
 
+static gboolean gimp_plug_in_procedure_validate_args   (GimpPlugInProcedure *proc,
+                                                        Gimp                *gimp,
+                                                        GimpValueArray      *args,
+                                                        GError             **error);
+
 
 G_DEFINE_TYPE (GimpPlugInProcedure, gimp_plug_in_procedure,
                GIMP_TYPE_PROCEDURE)
@@ -119,6 +127,7 @@ gimp_plug_in_procedure_class_init (GimpPlugInProcedureClass *klass)
   proc_class->get_label             = gimp_plug_in_procedure_get_label;
   proc_class->get_menu_label        = gimp_plug_in_procedure_get_menu_label;
   proc_class->get_blurb             = gimp_plug_in_procedure_get_blurb;
+  proc_class->get_help_id           = gimp_plug_in_procedure_get_help_id;
   proc_class->get_sensitive         = gimp_plug_in_procedure_get_sensitive;
   proc_class->execute               = gimp_plug_in_procedure_execute;
   proc_class->execute_async         = gimp_plug_in_procedure_execute_async;
@@ -132,7 +141,6 @@ gimp_plug_in_procedure_init (GimpPlugInProcedure *proc)
 {
   GIMP_PROCEDURE (proc)->proc_type = GIMP_PLUGIN;
 
-  proc->label            = NULL;
   proc->icon_data_length = -1;
 }
 
@@ -147,6 +155,7 @@ gimp_plug_in_procedure_finalize (GObject *object)
   g_list_free_full (proc->menu_paths, (GDestroyNotify) g_free);
 
   g_free (proc->label);
+  g_free (proc->help_id);
 
   g_free (proc->icon_data);
   g_free (proc->image_types);
@@ -305,6 +314,25 @@ gimp_plug_in_procedure_get_blurb (GimpProcedure *procedure)
   return NULL;
 }
 
+static const gchar *
+gimp_plug_in_procedure_get_help_id (GimpProcedure *procedure)
+{
+  GimpPlugInProcedure *proc = GIMP_PLUG_IN_PROCEDURE (procedure);
+  const gchar         *domain;
+
+  if (proc->help_id)
+    return proc->help_id;
+
+  domain = gimp_plug_in_procedure_get_help_domain (proc);
+
+  if (domain)
+    proc->help_id = g_strconcat (domain, "?", gimp_object_get_name (proc), NULL);
+  else
+    proc->help_id = g_strdup (gimp_object_get_name (proc));
+
+  return proc->help_id;
+}
+
 static gboolean
 gimp_plug_in_procedure_get_sensitive (GimpProcedure *procedure,
                                       GimpObject    *object)
@@ -360,6 +388,21 @@ gimp_plug_in_procedure_execute (GimpProcedure  *procedure,
                                 GimpValueArray *args,
                                 GError        **error)
 {
+  GimpPlugInProcedure *plug_in_procedure = GIMP_PLUG_IN_PROCEDURE (procedure);
+  GError              *pdb_error         = NULL;
+
+  if (! gimp_plug_in_procedure_validate_args (plug_in_procedure, gimp,
+                                              args, &pdb_error))
+    {
+      GimpValueArray *return_vals;
+
+      return_vals = gimp_procedure_get_return_values (procedure, FALSE,
+                                                      pdb_error);
+      g_propagate_error (error, pdb_error);
+
+      return return_vals;
+    }
+
   if (procedure->proc_type == GIMP_INTERNAL)
     return GIMP_PROCEDURE_CLASS (parent_class)->execute (procedure, gimp,
                                                          context, progress,
@@ -380,28 +423,93 @@ gimp_plug_in_procedure_execute_async (GimpProcedure  *procedure,
                                       GimpObject     *display)
 {
   GimpPlugInProcedure *plug_in_procedure = GIMP_PLUG_IN_PROCEDURE (procedure);
-  GimpValueArray      *return_vals;
+  GError              *error             = NULL;
 
-  return_vals = gimp_plug_in_manager_call_run (gimp->plug_in_manager,
-                                               context, progress,
-                                               plug_in_procedure,
-                                               args, FALSE, display);
-
-  if (return_vals)
+  if (gimp_plug_in_procedure_validate_args (plug_in_procedure, gimp,
+                                            args, &error))
     {
-      gimp_plug_in_procedure_handle_return_values (plug_in_procedure,
-                                                   gimp, progress,
-                                                   return_vals);
-      gimp_value_array_unref (return_vals);
+      GimpValueArray *return_vals;
+
+      return_vals = gimp_plug_in_manager_call_run (gimp->plug_in_manager,
+                                                   context, progress,
+                                                   plug_in_procedure,
+                                                   args, FALSE, display);
+
+      if (return_vals)
+        {
+          gimp_plug_in_procedure_handle_return_values (plug_in_procedure,
+                                                       gimp, progress,
+                                                       return_vals);
+          gimp_value_array_unref (return_vals);
+        }
+    }
+  else
+    {
+      gimp_message_literal (gimp, G_OBJECT (progress), GIMP_MESSAGE_ERROR,
+                            error->message);
+      g_error_free (error);
     }
 }
 
-GFile *
+static GFile *
 gimp_plug_in_procedure_real_get_file (const GimpPlugInProcedure *procedure)
 {
   return procedure->file;
 }
 
+static gboolean
+gimp_plug_in_procedure_validate_args (GimpPlugInProcedure *proc,
+                                      Gimp                *gimp,
+                                      GimpValueArray      *args,
+                                      GError             **error)
+{
+  if (proc->file_proc && proc->handles_uri)
+    {
+      /*  for file procedures that handle URIs, make sure that the
+       *  passed string actually is an URI, not just a file path
+       *  (bug 758685)
+       */
+      GimpProcedure *procedure = GIMP_PROCEDURE (proc);
+      GValue        *uri_value = NULL;
+
+      if ((procedure->num_args   >= 3)                     &&
+          (procedure->num_values >= 1)                     &&
+          GIMP_IS_PARAM_SPEC_INT32    (procedure->args[0]) &&
+          G_IS_PARAM_SPEC_STRING      (procedure->args[1]) &&
+          G_IS_PARAM_SPEC_STRING      (procedure->args[2]) &&
+          GIMP_IS_PARAM_SPEC_IMAGE_ID (procedure->values[0]))
+        {
+          uri_value = gimp_value_array_index (args, 1);
+        }
+      else if ((procedure->num_args >= 5)                          &&
+               GIMP_IS_PARAM_SPEC_INT32       (procedure->args[0]) &&
+               GIMP_IS_PARAM_SPEC_IMAGE_ID    (procedure->args[1]) &&
+               GIMP_IS_PARAM_SPEC_DRAWABLE_ID (procedure->args[2]) &&
+               G_IS_PARAM_SPEC_STRING         (procedure->args[3]) &&
+               G_IS_PARAM_SPEC_STRING         (procedure->args[4]))
+        {
+          uri_value = gimp_value_array_index (args, 3);
+        }
+
+      if (uri_value)
+        {
+          GFile *file;
+
+          file = file_utils_filename_to_file (gimp,
+                                              g_value_get_string (uri_value),
+                                              error);
+
+          if (! file)
+            return FALSE;
+
+          g_value_take_string (uri_value, g_file_get_uri (file));
+          g_object_unref (file);
+        }
+    }
+
+  return TRUE;
+}
+
 
 /*  public functions  */
 
@@ -692,7 +800,7 @@ gimp_plug_in_procedure_set_icon (GimpPlugInProcedure *proc,
 
   g_return_if_fail (GIMP_IS_PLUG_IN_PROCEDURE (proc));
 
-  switch (proc->icon_type)
+  switch (icon_type)
     {
     case GIMP_ICON_TYPE_ICON_NAME:
       data_copy = (guint8 *) g_strdup ((gchar *) icon_data);
@@ -763,7 +871,7 @@ gimp_plug_in_procedure_take_icon (GimpPlugInProcedure *proc,
 
   if (! icon_pixbuf && error)
     {
-      g_printerr ("%s\n", error->message);
+      g_printerr ("gimp_plug_in_procedure_take_icon: %s\n", error->message);
       g_clear_error (&error);
     }
 
@@ -774,21 +882,6 @@ gimp_plug_in_procedure_take_icon (GimpPlugInProcedure *proc,
     g_object_unref (icon_pixbuf);
 }
 
-gchar *
-gimp_plug_in_procedure_get_help_id (const GimpPlugInProcedure *proc)
-{
-  const gchar *domain;
-
-  g_return_val_if_fail (GIMP_IS_PLUG_IN_PROCEDURE (proc), NULL);
-
-  domain = gimp_plug_in_procedure_get_help_domain (proc);
-
-  if (domain)
-    return g_strconcat (domain, "?", gimp_object_get_name (proc), NULL);
-
-  return g_strdup (gimp_object_get_name (proc));
-}
-
 static GimpPlugInImageType
 image_types_parse (const gchar *name,
                    const gchar *image_types)
