@@ -438,7 +438,7 @@ sanity_check_gegl (void)
 
 #define GEGL_REQUIRED_MAJOR 0
 #define GEGL_REQUIRED_MINOR 3
-#define GEGL_REQUIRED_MICRO 4
+#define GEGL_REQUIRED_MICRO 6
 
   gegl_get_version (&gegl_major_version,
                     &gegl_minor_version,
@@ -507,6 +507,7 @@ sanity_check_gegl_ops (void)
     "gegl:gaussian-blur",
     "gegl:gaussian-blur-selective",
     "gegl:grid",
+    "gegl:high-pass",
     "gegl:illusion",
     "gegl:introspect",
     "gegl:invert-gamma",
@@ -542,6 +543,7 @@ sanity_check_gegl_ops (void)
     "gegl:polar-coordinates",
     "gegl:red-eye-removal",
     "gegl:ripple",
+    "gegl:saturation",
     "gegl:scale-ratio",
     "gegl:seamless-clone",
     "gegl:sepia",
