@@ -52,7 +52,6 @@
 #include "gimpconvolvetool.h"
 #include "gimpcroptool.h"
 #include "gimpcurvestool.h"
-#include "gimpdesaturatetool.h"
 #include "gimpdodgeburntool.h"
 #include "gimpellipseselecttool.h"
 #include "gimperasertool.h"
@@ -77,7 +76,6 @@
 #include "gimppenciltool.h"
 #include "gimpperspectiveclonetool.h"
 #include "gimpperspectivetool.h"
-#include "gimpposterizetool.h"
 #include "gimpthresholdtool.h"
 #include "gimprectangleselecttool.h"
 #include "gimprotatetool.h"
@@ -127,7 +125,6 @@ gimp_tools_init (Gimp *gimp)
     /*  color tools  */
     gimp_operation_tool_register,
     gimp_gegl_tool_register,
-    gimp_posterize_tool_register,
     gimp_curves_tool_register,
     gimp_levels_tool_register,
     gimp_threshold_tool_register,
@@ -135,7 +132,6 @@ gimp_tools_init (Gimp *gimp)
     gimp_colorize_tool_register,
     gimp_hue_saturation_tool_register,
     gimp_color_balance_tool_register,
-    gimp_desaturate_tool_register,
 
     /*  paint tools  */
 
