@@ -29,7 +29,7 @@
 
 #include "tools-types.h"
 
-#include "gegl/gimp-gegl-config-proxy.h"
+#include "gegl/gimp-gegl-config.h"
 #include "gegl/gimp-gegl-utils.h"
 
 #include "core/gimpchannel.h"
@@ -78,10 +78,12 @@ static void        gimp_operation_tool_control         (GimpTool          *tool,
                                                         GimpToolAction     action,
                                                         GimpDisplay       *display);
 
-static GeglNode  * gimp_operation_tool_get_operation   (GimpImageMapTool  *im_tool,
-                                                        GObject          **config,
-                                                        gchar            **undo_desc);
-static void        gimp_operation_tool_map             (GimpImageMapTool  *im_tool);
+static gchar     * gimp_operation_tool_get_operation   (GimpImageMapTool  *im_tool,
+                                                        gchar            **title,
+                                                        gchar            **description,
+                                                        gchar            **undo_desc,
+                                                        gchar            **icon_name,
+                                                        gchar            **help_id);
 static void        gimp_operation_tool_dialog          (GimpImageMapTool  *im_tool);
 static void        gimp_operation_tool_reset           (GimpImageMapTool  *im_tool);
 static GtkWidget * gimp_operation_tool_get_settings_ui (GimpImageMapTool  *im_tool,
@@ -146,10 +148,7 @@ gimp_operation_tool_class_init (GimpOperationToolClass *klass)
   tool_class->initialize         = gimp_operation_tool_initialize;
   tool_class->control            = gimp_operation_tool_control;
 
-  im_tool_class->dialog_desc     = _("GEGL Operation");
-
   im_tool_class->get_operation   = gimp_operation_tool_get_operation;
-  im_tool_class->map             = gimp_operation_tool_map;
   im_tool_class->dialog          = gimp_operation_tool_dialog;
   im_tool_class->reset           = gimp_operation_tool_reset;
   im_tool_class->get_settings_ui = gimp_operation_tool_get_settings_ui;
@@ -173,6 +172,18 @@ gimp_operation_tool_finalize (GObject *object)
       tool->operation = NULL;
     }
 
+  if (tool->title)
+    {
+      g_free (tool->title);
+      tool->title = NULL;
+    }
+
+  if (tool->description)
+    {
+      g_free (tool->description);
+      tool->description = NULL;
+    }
+
   if (tool->undo_desc)
     {
       g_free (tool->undo_desc);
@@ -185,6 +196,12 @@ gimp_operation_tool_finalize (GObject *object)
       tool->icon_name = NULL;
     }
 
+  if (tool->help_id)
+    {
+      g_free (tool->help_id);
+      tool->help_id = NULL;
+    }
+
   g_list_free_full (tool->aux_inputs,
                     (GDestroyNotify) gimp_operation_tool_aux_input_free);
   tool->aux_inputs = NULL;
@@ -238,36 +255,23 @@ gimp_operation_tool_control (GimpTool       *tool,
   GIMP_TOOL_CLASS (parent_class)->control (tool, action, display);
 }
 
-static GeglNode *
+static gchar *
 gimp_operation_tool_get_operation (GimpImageMapTool  *im_tool,
-                                   GObject          **config,
-                                   gchar            **undo_desc)
+                                   gchar            **title,
+                                   gchar            **description,
+                                   gchar            **undo_desc,
+                                   gchar            **icon_name,
+                                   gchar            **help_id)
 {
   GimpOperationTool *tool = GIMP_OPERATION_TOOL (im_tool);
 
-  if (tool->operation)
-    *config = G_OBJECT (gimp_gegl_get_config_proxy (tool->operation,
-                                                    GIMP_TYPE_SETTINGS));
+  *title       = g_strdup (tool->title);
+  *description = g_strdup (tool->description);
+  *undo_desc   = g_strdup (tool->undo_desc);
+  *icon_name   = g_strdup (tool->icon_name);
+  *help_id     = g_strdup (tool->help_id);
 
-  if (tool->undo_desc)
-    *undo_desc = g_strdup (tool->undo_desc);
-
-  if (tool->operation)
-    return gegl_node_new_child (NULL,
-                                "operation", tool->operation,
-                                NULL);
-
-  return gegl_node_new_child (NULL,
-                              "operation", "gegl:nop",
-                              NULL);
-}
-
-static void
-gimp_operation_tool_map (GimpImageMapTool *im_tool)
-{
-  if (im_tool->config)
-    gimp_gegl_config_proxy_sync (GIMP_OBJECT (im_tool->config),
-                                 im_tool->operation);
+  return g_strdup (tool->operation);
 }
 
 static void
@@ -282,7 +286,7 @@ gimp_operation_tool_dialog (GimpImageMapTool *im_tool)
   /*  The options vbox  */
   tool->options_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
   gtk_box_pack_start (GTK_BOX (main_vbox), tool->options_box,
-                      FALSE, FALSE, 0);
+                      TRUE, TRUE, 0);
   gtk_widget_show (tool->options_box);
 
   for (list = tool->aux_inputs; list; list = g_list_next (list))
@@ -300,14 +304,6 @@ gimp_operation_tool_dialog (GimpImageMapTool *im_tool)
                           FALSE, FALSE, 0);
       gtk_widget_show (tool->options_gui);
     }
-
-  if (tool->undo_desc)
-    gimp_tool_gui_set_description (GIMP_IMAGE_MAP_TOOL (tool)->gui,
-                                   tool->undo_desc);
-
-  if (tool->icon_name)
-    gimp_tool_gui_set_icon_name (GIMP_IMAGE_MAP_TOOL (tool)->gui,
-                                 tool->icon_name);
 }
 
 static void
@@ -332,25 +328,19 @@ gimp_operation_tool_get_settings_ui (GimpImageMapTool  *im_tool,
                                      GtkWidget        **settings_box)
 {
   GimpOperationTool *tool = GIMP_OPERATION_TOOL (im_tool);
-  GType              type = G_TYPE_FROM_INSTANCE (im_tool->config);
   GtkWidget         *widget;
   gchar             *basename;
   GFile             *file;
   gchar             *import_title;
   gchar             *export_title;
 
-  settings = gimp_gegl_get_config_container (type);
-  if (! gimp_list_get_sort_func (GIMP_LIST (settings)))
-    gimp_list_set_sort_func (GIMP_LIST (settings),
-                             (GCompareFunc) gimp_settings_compare);
-
   basename = g_strconcat (G_OBJECT_TYPE_NAME (im_tool->config),
                           ".settings", NULL);
   file = gimp_directory_file ("filters", basename, NULL);
   g_free (basename);
 
-  import_title = g_strdup_printf (_("Import '%s' Settings"), tool->undo_desc);
-  export_title = g_strdup_printf (_("Export '%s' Settings"), tool->undo_desc);
+  import_title = g_strdup_printf (_("Import '%s' Settings"), tool->title);
+  export_title = g_strdup_printf (_("Export '%s' Settings"), tool->title);
 
   widget =
     GIMP_IMAGE_MAP_TOOL_CLASS (parent_class)->get_settings_ui (im_tool,
@@ -620,8 +610,11 @@ gimp_operation_tool_aux_input_free (AuxInput *input)
 void
 gimp_operation_tool_set_operation (GimpOperationTool *tool,
                                    const gchar       *operation,
+                                   const gchar       *title,
+                                   const gchar       *description,
                                    const gchar       *undo_desc,
-                                   const gchar       *icon_name)
+                                   const gchar       *icon_name,
+                                   const gchar       *help_id)
 {
   GimpImageMapTool *im_tool;
   GtkSizeGroup     *size_group = NULL;
@@ -635,15 +628,27 @@ gimp_operation_tool_set_operation (GimpOperationTool *tool,
   if (tool->operation)
     g_free (tool->operation);
 
+  if (tool->title)
+    g_free (tool->title);
+
+  if (tool->description)
+    g_free (tool->description);
+
   if (tool->undo_desc)
     g_free (tool->undo_desc);
 
   if (tool->icon_name)
     g_free (tool->icon_name);
 
-  tool->operation = g_strdup (operation);
-  tool->undo_desc = g_strdup (undo_desc);
-  tool->icon_name = g_strdup (icon_name);
+  if (tool->help_id)
+    g_free (tool->help_id);
+
+  tool->operation   = g_strdup (operation);
+  tool->title       = g_strdup (title);
+  tool->description = g_strdup (description);
+  tool->undo_desc   = g_strdup (undo_desc);
+  tool->icon_name   = g_strdup (icon_name);
+  tool->help_id     = g_strdup (help_id);
 
   g_list_free_full (tool->aux_inputs,
                     (GDestroyNotify) gimp_operation_tool_aux_input_free);
@@ -721,7 +726,7 @@ gimp_operation_tool_set_operation (GimpOperationTool *tool,
     {
       tool->options_gui =
         gimp_prop_gui_new (G_OBJECT (im_tool->config),
-                           G_TYPE_FROM_INSTANCE (im_tool->config),
+                           G_TYPE_FROM_INSTANCE (im_tool->config), 0,
                            GIMP_CONTEXT (GIMP_TOOL_GET_OPTIONS (tool)),
                            (GimpCreatePickerFunc) gimp_image_map_tool_add_color_picker,
                            tool);
@@ -729,20 +734,11 @@ gimp_operation_tool_set_operation (GimpOperationTool *tool,
       if (tool->options_box)
         {
           gtk_box_pack_start (GTK_BOX (tool->options_box), tool->options_gui,
-                              FALSE, FALSE, 0);
+                              TRUE, TRUE, 0);
           gtk_widget_show (tool->options_gui);
         }
     }
 
-  if (im_tool->gui)
-    {
-      if (undo_desc)
-        gimp_tool_gui_set_description (im_tool->gui, undo_desc);
-
-      if (icon_name)
-        gimp_tool_gui_set_icon_name (im_tool->gui, icon_name);
-    }
-
   if (GIMP_TOOL (tool)->drawable)
     {
       gimp_operation_tool_sync_op (tool, GIMP_TOOL (tool)->drawable);
