@@ -174,18 +174,20 @@ gimp_warp_tool_init (GimpWarpTool *self)
 {
   GimpTool *tool = GIMP_TOOL (self);
 
-  gimp_tool_control_set_preserve    (tool->control, FALSE);
-  gimp_tool_control_set_motion_mode (tool->control, GIMP_MOTION_MODE_EXACT);
-  gimp_tool_control_set_dirty_mask  (tool->control,
-                                     GIMP_DIRTY_IMAGE           |
-                                     GIMP_DIRTY_DRAWABLE        |
-                                     GIMP_DIRTY_SELECTION       |
-                                     GIMP_DIRTY_ACTIVE_DRAWABLE);
-  gimp_tool_control_set_wants_click (tool->control, TRUE);
-  gimp_tool_control_set_tool_cursor (tool->control,
-                                     GIMP_TOOL_CURSOR_PERSPECTIVE);
-  gimp_tool_control_set_action_size (tool->control,
-                                     "tools/tools-warp-effect-size-set");
+  gimp_tool_control_set_preserve        (tool->control, FALSE);
+  gimp_tool_control_set_motion_mode     (tool->control, GIMP_MOTION_MODE_EXACT);
+  gimp_tool_control_set_dirty_mask      (tool->control,
+                                         GIMP_DIRTY_IMAGE           |
+                                         GIMP_DIRTY_DRAWABLE        |
+                                         GIMP_DIRTY_SELECTION       |
+                                         GIMP_DIRTY_ACTIVE_DRAWABLE);
+  gimp_tool_control_set_wants_click     (tool->control, TRUE);
+  gimp_tool_control_set_tool_cursor     (tool->control,
+                                         GIMP_TOOL_CURSOR_PERSPECTIVE);
+  gimp_tool_control_set_action_size     (tool->control,
+                                         "tools/tools-warp-effect-size-set");
+  gimp_tool_control_set_action_hardness (tool->control,
+                                         "tools/tools-warp-effect-hardness-set");
 }
 
 static void
