@@ -20,8 +20,6 @@
 
 #include "config.h"
 
-#include <string.h>
-
 #include <gegl.h>
 #include <gtk/gtk.h>
 
@@ -37,8 +35,7 @@
 
 #include "config/gimpguiconfig.h"
 
-#include "pdb/gimppdb.h"
-
+#include "plug-in/gimppluginmanager-file.h"
 #include "plug-in/gimppluginprocedure.h"
 
 #include "gimpfiledialog.h"
@@ -178,6 +175,7 @@ gimp_file_dialog_class_init (GimpFileDialogClass *klass)
                                                         GIMP_TYPE_GIMP,
                                                         GIMP_PARAM_READWRITE |
                                                         G_PARAM_CONSTRUCT_ONLY));
+
   g_object_class_install_property (object_class, PROP_HELP_ID,
                                    g_param_spec_string ("help-id", NULL, NULL,
                                                         NULL,
@@ -187,38 +185,51 @@ gimp_file_dialog_class_init (GimpFileDialogClass *klass)
   g_object_class_install_property (object_class, PROP_STOCK_ID,
                                    g_param_spec_string ("stock-id", NULL, NULL,
                                                         NULL,
-                                                        GIMP_PARAM_READWRITE |
+                                                        GIMP_PARAM_WRITABLE |
                                                         G_PARAM_CONSTRUCT_ONLY));
+
   g_object_class_install_property (object_class, PROP_AUTOMATIC_HELP_ID,
-                                   g_param_spec_string ("automatic-help-id", NULL, NULL,
+                                   g_param_spec_string ("automatic-help-id",
+                                                        NULL, NULL,
                                                         NULL,
-                                                        GIMP_PARAM_READWRITE |
+                                                        GIMP_PARAM_WRITABLE |
                                                         G_PARAM_CONSTRUCT_ONLY));
+
   g_object_class_install_property (object_class, PROP_AUTOMATIC_LABEL,
-                                   g_param_spec_string ("automatic-label", NULL, NULL,
+                                   g_param_spec_string ("automatic-label",
+                                                        NULL, NULL,
                                                         NULL,
-                                                        GIMP_PARAM_READWRITE |
+                                                        GIMP_PARAM_WRITABLE |
                                                         G_PARAM_CONSTRUCT_ONLY));
 
   g_object_class_install_property (object_class, PROP_FILE_FILTER_LABEL,
-                                   g_param_spec_string ("file-filter-label", NULL, NULL,
+                                   g_param_spec_string ("file-filter-label",
+                                                        NULL, NULL,
                                                         NULL,
-                                                        GIMP_PARAM_READWRITE |
+                                                        GIMP_PARAM_WRITABLE |
                                                         G_PARAM_CONSTRUCT_ONLY));
+
   g_object_class_install_property (object_class, PROP_FILE_PROCS,
-                                   g_param_spec_pointer ("file-procs", NULL, NULL,
-                                                        GIMP_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY));
+                                   g_param_spec_enum ("file-procs",
+                                                      NULL, NULL,
+                                                      GIMP_TYPE_FILE_PROCEDURE_GROUP,
+                                                      GIMP_FILE_PROCEDURE_GROUP_NONE,
+                                                      GIMP_PARAM_WRITABLE |
+                                                      G_PARAM_CONSTRUCT_ONLY));
+
   g_object_class_install_property (object_class, PROP_FILE_PROCS_ALL_IMAGES,
-                                   g_param_spec_pointer ("file-procs-all-images", NULL, NULL,
-                                                        GIMP_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY));
+                                   g_param_spec_enum ("file-procs-all-images",
+                                                      NULL, NULL,
+                                                      GIMP_TYPE_FILE_PROCEDURE_GROUP,
+                                                      GIMP_FILE_PROCEDURE_GROUP_NONE,
+                                                      GIMP_PARAM_WRITABLE |
+                                                      G_PARAM_CONSTRUCT_ONLY));
 }
 
 static void
 gimp_file_dialog_init (GimpFileDialog *dialog)
 {
-  dialog->stock_id = GTK_STOCK_OK;
+ dialog->stock_id = GTK_STOCK_OK;
 }
 
 static void
@@ -240,7 +251,7 @@ gimp_file_dialog_set_property (GObject      *object,
                                const GValue *value,
                                GParamSpec   *pspec)
 {
-  GimpFileDialog        *dialog  = GIMP_FILE_DIALOG (object);
+  GimpFileDialog *dialog = GIMP_FILE_DIALOG (object);
 
   switch (property_id)
     {
@@ -263,10 +274,14 @@ gimp_file_dialog_set_property (GObject      *object,
       dialog->file_filter_label = g_value_dup_string (value);
       break;
     case PROP_FILE_PROCS:
-      dialog->file_procs = g_value_get_pointer (value);
+      dialog->file_procs =
+        gimp_plug_in_manager_get_file_procedures (dialog->gimp->plug_in_manager,
+                                                  g_value_get_enum (value));
       break;
     case PROP_FILE_PROCS_ALL_IMAGES:
-      dialog->file_procs_all_images = g_value_get_pointer (value);
+      dialog->file_procs_all_images =
+        gimp_plug_in_manager_get_file_procedures (dialog->gimp->plug_in_manager,
+                                                  g_value_get_enum (value));
       break;
 
     default:
@@ -281,7 +296,7 @@ gimp_file_dialog_get_property (GObject    *object,
                                GValue     *value,
                                GParamSpec *pspec)
 {
-  GimpFileDialog        *dialog  = GIMP_FILE_DIALOG (object);
+  GimpFileDialog *dialog = GIMP_FILE_DIALOG (object);
 
   switch (property_id)
     {
@@ -315,6 +330,10 @@ gimp_file_dialog_constructed (GObject *object)
                                            GTK_RESPONSE_CANCEL,
                                            -1);
 
+  gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (object), FALSE);
+  gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (object),
+                                                  TRUE);
+
   if (dialog->help_id)
     {
       gimp_help_connect (GTK_WIDGET (dialog),
@@ -428,20 +447,27 @@ gimp_file_dialog_real_get_default_folder (GimpFileDialog *dialog)
     }
   else
     {
-      /* The default folder is "Documents" for all file dialogs.
-       * Children can reimplement this. */
       file = g_object_get_data (G_OBJECT (dialog->gimp),
-                                "gimp-documents-folder");
+                                "gimp-default-folder");
 
       if (! file)
         {
           gchar *path;
 
-          /* Make sure it ends in '/' */
+          /* Make sure the paths end with G_DIR_SEPARATOR_S */
+
+#ifdef PLATFORM_OSX
+          /* See bug 753683, "Desktop" is expected on OS X */
+          path = g_build_path (G_DIR_SEPARATOR_S,
+                               g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP),
+                               G_DIR_SEPARATOR_S,
+                               NULL);
+#else
           path = g_build_path (G_DIR_SEPARATOR_S,
                                g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS),
                                G_DIR_SEPARATOR_S,
                                NULL);
+#endif
 
           /* Paranoia fallback, see bug #722400 */
           if (! path)
@@ -453,10 +479,12 @@ gimp_file_dialog_real_get_default_folder (GimpFileDialog *dialog)
           file = g_file_new_for_path (path);
           g_free (path);
 
-          g_object_set_data_full (G_OBJECT (dialog->gimp), "gimp-documents-folder",
+          g_object_set_data_full (G_OBJECT (dialog->gimp),
+                                  "gimp-default-folder",
                                   file, (GDestroyNotify) g_object_unref);
         }
     }
+
   return file;
 }
 
@@ -882,7 +910,8 @@ gimp_file_dialog_add_proc_selection (GimpFileDialog *dialog)
 
   gtk_widget_set_size_request (scrolled_window, -1, 200);
 
-  dialog->proc_view = gimp_file_proc_view_new (dialog->gimp, dialog->file_procs,
+  dialog->proc_view = gimp_file_proc_view_new (dialog->gimp,
+                                               dialog->file_procs,
                                                dialog->automatic_label,
                                                dialog->automatic_help_id);
   gtk_container_add (GTK_CONTAINER (scrolled_window), dialog->proc_view);
