@@ -74,6 +74,8 @@
 #define GIMP_HELP_SELECTION_SHRINK                "gimp-selection-shrink"
 #define GIMP_HELP_SELECTION_GROW                  "gimp-selection-grow"
 #define GIMP_HELP_SELECTION_BORDER                "gimp-selection-border"
+#define GIMP_HELP_SELECTION_FLOOD                 "gimp-selection-flood"
+#define GIMP_HELP_SELECTION_FILL                  "gimp-selection-fill"
 #define GIMP_HELP_SELECTION_STROKE                "gimp-selection-stroke"
 #define GIMP_HELP_SELECTION_TO_CHANNEL            "gimp-selection-to-channel"
 #define GIMP_HELP_SELECTION_TO_PATH               "gimp-selection-to-path"
@@ -257,6 +259,7 @@
 #define GIMP_HELP_PATH_SELECTION_ADD              "gimp-path-selection-add"
 #define GIMP_HELP_PATH_SELECTION_SUBTRACT         "gimp-path-selection-subtract"
 #define GIMP_HELP_PATH_SELECTION_INTERSECT        "gimp-path-selection-intersect"
+#define GIMP_HELP_PATH_FILL                       "gimp-path-fill"
 #define GIMP_HELP_PATH_STROKE                     "gimp-path-stroke"
 #define GIMP_HELP_PATH_COPY                       "gimp-path-copy"
 #define GIMP_HELP_PATH_PASTE                      "gimp-path-paste"
@@ -557,6 +560,7 @@
 #define GIMP_HELP_INFO_DIALOG                     "gimp-info-dialog"
 #define GIMP_HELP_MODULE_DIALOG                   "gimp-module-dialog"
 #define GIMP_HELP_NAVIGATION_DIALOG               "gimp-navigation-dialog"
+#define GIMP_HELP_SYMMETRY_DIALOG                 "gimp-symmetry-dialog"
 #define GIMP_HELP_TEXT_EDITOR_DIALOG              "gimp-text-editor-dialog"
 #define GIMP_HELP_TIPS_DIALOG                     "gimp-tips-dialog"
 #define GIMP_HELP_UNDO_DIALOG                     "gimp-undo-dialog"
