@@ -773,7 +773,7 @@ gimp_plug_in_directory_file (const gchar *first_element,
 const gchar *
 gimp_user_directory (GimpUserDirectory type)
 {
-  return g_get_user_special_dir (type);
+  return g_get_user_special_dir ((GUserDirectory) type);
 }
 
 /**
@@ -814,7 +814,7 @@ gimp_gtkrc (void)
 
   if (! gimp_gtkrc_filename)
     gimp_gtkrc_filename = g_build_filename (gimp_data_directory (),
-                                            "themes", "Default", "gtkrc",
+                                            "themes", "System", "gtkrc",
                                             NULL);
 
   return gimp_gtkrc_filename;
