@@ -116,7 +116,7 @@ static gboolean          raw_load_palette    (RawGimpData      *data,
                                               const gchar      *palette_filename);
 
 /* support functions */
-static gint32            get_file_info       (const gchar      *filename);
+static goffset           get_file_info       (const gchar      *filename);
 static void              raw_read_row        (FILE             *fp,
                                               guchar           *buf,
                                               gint32            offset,
@@ -375,14 +375,28 @@ run (const gchar      *name,
 
 
 /* get file size from a filename */
-static gint32
+static goffset
 get_file_info (const gchar *filename)
 {
-  struct stat status;
+  GFile     *file = g_file_new_for_path (filename);
+  GFileInfo *info;
+  goffset    size = 0;
 
-  g_stat (filename, &status);
+  info = g_file_query_info (file,
+                            G_FILE_ATTRIBUTE_STANDARD_SIZE,
+                            G_FILE_QUERY_INFO_NONE,
+                            NULL, NULL);
 
-  return status.st_size;
+  if (info)
+    {
+      size = g_file_info_get_size (info);
+
+      g_object_unref (info);
+    }
+
+  g_object_unref (file);
+
+  return size;
 }
 
 /* new image handle functions */
@@ -878,7 +892,7 @@ load_image (const gchar  *filename,
   gint32             layer_id = -1;
   GimpImageType      ltype    = GIMP_RGB;
   GimpImageBaseType  itype    = GIMP_RGB_IMAGE;
-  gint32             size;
+  goffset            size;
   gint               bpp = 0;
   gint               bitspp = 8;
 
@@ -1340,13 +1354,13 @@ load_dialog (const gchar *filename)
   GtkWidget     *dialog;
   GtkWidget     *main_vbox;
   GtkWidget     *preview;
-  GtkWidget     *table;
   GtkWidget     *sw;
   GtkWidget     *frame;
+  GtkWidget     *table;
   GtkWidget     *combo;
   GtkWidget     *button;
   GtkAdjustment *adj;
-  gint32         file_size;
+  goffset        file_size;
   gboolean       run;
 
   file_size = get_file_info (filename);
